@@ -299,7 +299,7 @@ public class JAXBExtensionHelper implements ExtensionSerializer, ExtensionDeseri
                 if (method.getParameterTypes().length == 1
                     && method.getParameterTypes()[0].equals(typeClass)) {
 
-                    mObj = method.invoke(objectFactory.newInstance(), new Object[] {obj});
+                    mObj = method.invoke(objectFactory.getDeclaredConstructor().newInstance(), new Object[] {obj});
                 }
             }
 
@@ -401,7 +401,8 @@ public class JAXBExtensionHelper implements ExtensionSerializer, ExtensionDeseri
                     return ctx.getPrefix(namespaceURI);
                 }
 
-                public Iterator<String> getPrefixes(String namespaceURI) {
+                @SuppressWarnings("rawtypes")
+                public Iterator getPrefixes(String namespaceURI) {
                     if (jaxbNamespace.equals(namespaceURI)) {
                         return ctx.getPrefixes(namespace);
                     }
